==> haskell-yesod-default-1.2.0-405-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-9BNE5h3tHppAigRIwbQuQ4
key: yesod-default-1.2.0-9BNE5h3tHppAigRIwbQuQ4
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
author: Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
abi: f1d6ddea8fb647fc335515145b3a1b9e
exposed: True
exposed-modules:
    Yesod.Default.Ignore
import-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-9BNE5h3tHppAigRIwbQuQ4
depends:
    base-4.11.1.0 yesod-core-1.6.6-9FKBY6dKO347pAvsO4cnJR
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             yesod-core-1.6.6-9FKBY6dKO347pAvsO4cnJR=4f6a2e91037b3415fcf5f344a6513af5
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-default-1.2.0-406-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-8zlZmkRwSmlBluj87ie3D2
key: yesod-default-1.2.0-8zlZmkRwSmlBluj87ie3D2
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
author: Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
abi: 306df8cb26b3dc883e4deee8aff1b59b
exposed: True
exposed-modules:
    Yesod.Default.Ignore
import-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-8zlZmkRwSmlBluj87ie3D2
depends:
    base-4.11.1.0 yesod-core-1.6.6-7ycnTC77Qmbjv0cL6SQ08
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             yesod-core-1.6.6-7ycnTC77Qmbjv0cL6SQ08=ab926b31dac424efc89354e56fe23133
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
